==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebForOfStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDescriptionMetadata } from "./WebBaseEventArgsDescriptionMetadata";
import { WebForOfStateDescription } from "./WebForOfStateDescription";
/**
 * @hidden
 */
var WebForOfStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfStateDescriptionMetadata, _super);
    function WebForOfStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateDescriptionMetadata.b = function (a) {
        if (WebForOfStateDescriptionMetadata.a == null) {
            WebForOfStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateDescriptionMetadata.c(WebForOfStateDescriptionMetadata.a);
        }
        if (a.j(WebForOfStateDescriptionMetadata.a)) {
            return;
        }
        a.y(WebForOfStateDescriptionMetadata.a);
    };
    WebForOfStateDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfState");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("StartIndex", "Number:double");
        a.item("ChunkSize", "Number:double");
    };
    WebForOfStateDescriptionMetadata.d = function (a) {
        WebForOfStateDescriptionMetadata.b(a);
        a.aa("WebForOfState", function () { return new WebForOfStateDescription(); });
        a.z("WebForOfState", WebForOfStateDescriptionMetadata.a);
    };
    WebForOfStateDescriptionMetadata.$t = markType(WebForOfStateDescriptionMetadata, 'WebForOfStateDescriptionMetadata');
    WebForOfStateDescriptionMetadata.a = null;
    return WebForOfStateDescriptionMetadata;
}(Base));
export { WebForOfStateDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebForOfStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDescriptionMetadata } from "./WebBaseEventArgsDescriptionMetadata";
import { WebForOfStateDescription } from "./WebForOfStateDescription";
/**
 * @hidden
 */
var WebForOfStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfStateDescriptionMetadata, _super);
    function WebForOfStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateDescriptionMetadata.b = function (a) {
        if (WebForOfStateDescriptionMetadata.a == null) {
            WebForOfStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateDescriptionMetadata.c(WebForOfStateDescriptionMetadata.a);
        }
        if (a.k(WebForOfStateDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebForOfStateDescriptionMetadata.a);
    };
    WebForOfStateDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfState");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("StartIndex", "Number:double");
        a.item("ChunkSize", "Number:double");
    };
    WebForOfStateDescriptionMetadata.d = function (a) {
        WebForOfStateDescriptionMetadata.b(a);
        a.ac("WebForOfState", function () { return new WebForOfStateDescription(); });
        a.ab("WebForOfState", WebForOfStateDescriptionMetadata.a);
    };
    WebForOfStateDescriptionMetadata.$t = markType(WebForOfStateDescriptionMetadata, 'WebForOfStateDescriptionMetadata');
    WebForOfStateDescriptionMetadata.a = null;
    return WebForOfStateDescriptionMetadata;
}(Base));
export { WebForOfStateDescriptionMetadata };
